#!/usr/bin/env python3
"""
FTP Connection Tester
Parameters:
    - IP: Target IP address
    - port: Target port (default: 21)
Additional parameters in comments:
    - username: FTP username
    - password: FTP password
"""
from ftplib import FTP
import argparse
import sys

def test_ftp(ip, port=21):
    try:
        # Connect to FTP server
        ftp = FTP()
        ftp.connect(ip, port, timeout=10)
        
        # Get banner
        banner = ftp.getwelcome()
        print(f"FTP Banner: {banner}")
        
        # Try anonymous login
        try:
            ftp.login()
            print("Anonymous login successful!")
            # List directory contents
            files = ftp.nlst()
            print("Directory listing:")
            for file in files[:10]:  # Show first 10 files
                print(f"- {file}")
        except:
            print("Anonymous login failed")
            
        ftp.quit()
    except Exception as e:
        print(f"Error: {str(e)}")
        sys.exit(1)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="FTP Connection Tester")
    parser.add_argument("ip", help="Target IP address")
    parser.add_argument("--port", type=int, default=21, help="Target port (default: 21)")
    args = parser.parse_args()
    
    test_ftp(args.ip, args.port)
